<?php

namespace Drupal\gdpr_compliance\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * Controller routines for page routes.
 */
class PagePolicy extends ControllerBase {

  /**
   * Construct.
   */
  public function __construct() {
    $lang = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $this->lang = 'en';
    $langs = ['en', 'ru'];
    if (in_array($lang, $langs)) {
      $this->lang = $lang;
    }
  }

  /**
   * Page Title.
   */
  public function title() {
    $titles = [
      'en' => $this->t('Privacy and Cookie policy'),
      'ru' => $this->t('Соглашение об использовании персональных данных'),
    ];
    $title = $titles[$this->lang];
    return $title;
  }

  /**
   * Constructs page from template.
   */
  public function page() {
    $path = \Drupal::service('module_handler')->getModule('gdpr_compliance')->getPath();
    $policy = DRUPAL_ROOT . "/$path/assets/policy/policy-" . $this->lang . ".html";
    return [
      'policy' => [
        '#type' => 'inline_template',
        '#template' => file_get_contents($policy),
        '#context' => [
          'changed' => format_date(filemtime($policy), 'medium'),
          'url' => $host = \Drupal::request()->getHost(),
          'mail' => \Drupal::config('system.site')->get('mail'),
        ],
      ],
    ];
  }

}
